package com.sundot.airport.item.service;

import com.sundot.airport.item.domain.HkOperationData;

import java.util.List;

public interface IHkOperationDataService {

    List<HkOperationData> selectHkOperationDataList(HkOperationData query);

    HkOperationData selectHkOperationDataById(Long id);

    int insertHkOperationData(HkOperationData data);

    int updateHkOperationData(HkOperationData data);

    int deleteHkOperationDataByIds(Long[] ids);

    String importData(List<HkOperationData> list);
}
